#!/bin/sh

###################################################################
#Script Name	: assembly64.sh
#Description	: Start/stop of assembly64
#Args         : start|stop|log|verbose
#Authors      : Fredrik Aaberg aka Scooby/Genesis Project
#               DHA81
#Email        : freabe@gmail.com
###################################################################
if [ -z "${JAVA_HOME}" ]; then
  echo 'JAVA_HOME was not set, please download java17 or later and set JAVA_HOME'
  exit 0
fi

if [ -z "${JFX_HOME}" ]; then
  echo 'JFX_HOME was not set, please download JAVAFX 17.0.1 SDK from https://gluonhq.com/products/javafx/ and set JXF_HOME pointing to it'
  exit 0
fi

case $1 in
  start)
    if ps -ef|grep 'java' | grep -wc 'assembly64-latest.jar' > /dev/null; then
      echo 'Assembly64 is already running'
      exit 0
    fi
    echo 'Starting Assembly64'
    echo 'Using JAVA_HOME:' $JAVA_HOME
    $JAVA_HOME/bin/java --module-path $JFX_HOME/lib  --add-modules=javafx.controls,javafx.graphics,javafx.fxml,javafx.base -jar runtime/assembly64-latest.jar > /dev/null &
    ;;
    log)
    if ps -ef|grep 'java' | grep -wc 'assembly64-latest.jar' > /dev/null; then
      echo 'Assembly64 is already running'
      exit 0
    fi
    echo 'Starting Assembly64'
    echo 'Using JAVA_HOME:' $JAVA_HOME
    $JAVA_HOME/bin/java --module-path $JFX_HOME/lib  --add-modules=javafx.controls,javafx.graphics,javafx.fxml,javafx.base -jar runtime/assembly64-latest.jar >assembly64.log &
    ;;
    verbose)
    if ps -ef|grep 'java' | grep -wc 'assembly64-latest.jar' > /dev/null; then
      echo 'Assembly64 is already running'
      exit 0
    fi
    echo 'Starting Assembly64'
    echo 'Using JAVA_HOME:' $JAVA_HOME
    $JAVA_HOME/bin/java --module-path $JFX_HOME/lib  --add-modules=javafx.controls,javafx.graphics,javafx.fxml,javafx.base -jar runtime/assembly64-latest.jar &
    ;;
  stop)
    if ps -ef|grep 'java' | grep -wc 'assembly64-latest.jar' > /dev/null; then
      echo 'Shutting down assembly64'
      kill $(ps aux | grep '[a]ssembly64-latest.jar' | awk '{print $2}') > /dev/null &
      echo 'Done...'
    else
      echo 'Assembly64 was not running'
    fi
    ;;
  *)
    echo 'usage: assembly64.sh start|stop'
esac
